==> inti-moto-cli-1.0.0-01683b.tar: src/Schema/Create.php <==
<?php
declare(strict_types=1);

namespace Inti\Moto\Console\Schema;

use Doctrine\DBAL\Connection;
use Doctrine\DBAL\Schema\SchemaException;
use Doctrine\DBAL\Schema\Table;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Throwable;
use function method_exists;

/**
 * Class CreateSchema
 *
 * @package Inti\Moto\Console\Schema
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-moto-cli
 */
final class Create extends Command
{
    private Connection $conn;

    private array $tables = [
        'image',
        'make',
        'model',
        'category',
        'engine_type',
        'engine',
        'fuel_system',
        'fuel_control',
        'ignition',
        'lubrication_system',
        'cooling_system',
        'gearbox',
        'transmission_type',
        'clutch',
        'exhaust_system',
        'suspension',
        'brake',
        'starter',
        'electrical',
        'bike',
    ];

    public function __construct(Connection $conn)
    {
        parent::__construct('schema:create');
        $this->conn = $conn;
    }

    protected function configure(): void
    {
        $this->setDescription('Stvara potrebne tablice u bazi.');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        try {
            $manager = $this->conn->getSchemaManager();
            $fromSchema = $manager->createSchema();
            $toSchema = clone $fromSchema;

            foreach ($this->tables as $tableName) {

                $table = $toSchema->hasTable($tableName)
                    ? $toSchema->getTable($tableName)
                    : $toSchema->createTable($tableName);

                if (method_exists($this, $tableName)) {
                    $this->$tableName($table);
                } else {
                    $this->_name_table($table);
                }
            }

            $sql = $fromSchema->getMigrateToSql($toSchema, $this->conn->getDatabasePlatform());

            foreach ($sql as $query) {
                $this->conn->executeQuery($query);
            }

            return Command::SUCCESS;
        } catch (Throwable $e) {
            $output->writeln([
                'Došlo je do neakve pogreške:',
                isset($query) ? '============================' : '',
                isset($query) ? $query : '',
                '============================',
                $e->getMessage(),
            ]);

            return Command::FAILURE;
        }
    }

    /**
     * @param Table $table
     * @throws SchemaException
     * @noinspection PhpUnusedPrivateMethodInspection
     */
    private function image(Table $table): void
    {
        $this->_id($table);

        if (!$table->hasColumn('url')) {
            $table->addColumn('url', 'string', ['length' => 191]);
            $table->addUniqueIndex(['url'], 'url');
        }
    }

    /**
     * @param Table $table
     * @throws SchemaException
     * @noinspection PhpUnusedPrivateMethodInspection
     */
    private function make(Table $table): void
    {
        $this->_id($table);

        $table->hasColumn('name') || $table->addColumn('name', 'string', [
            'length' => 191,
        ]);
        $table->hasIndex('name') || $table->addUniqueIndex(['name'], 'name');
    }

    /**
     * @param Table $table
     * @throws SchemaException
     * @noinspection PhpUnusedPrivateMethodInspection
     */
    private function model(Table $table): void
    {
        $this->_id($table);
        $this->_make_id($table);

        $table->hasColumn('name') || $table->addColumn('name', 'string', [
            'length' => 191,
        ]);
        $table->hasIndex('name') || $table->addIndex(['name'], 'name');
    }

    /**
     * @param Table $table
     * @throws SchemaException
     * @noinspection PhpUnusedPrivateMethodInspection
     */
    private function bike(Table $table): void
    {
        $this->_id($table);

        $this->_make_id($table);

        if (!$table->hasColumn('model_id')) {
            $table->addColumn('model_id', 'bigint', ['unsigned' => true]);
            $table->addIndex(['model_id'], 'model_id');
            $table->addForeignKeyConstraint('model', ['model_id'], ['id'], [], 'model');
        }

        if (!$table->hasColumn('year')) {
            $table->addColumn('year', 'integer');
            $table->addIndex(['year'], 'year');
        }

        if (!$table->hasColumn('category_id')) {
            $table->addColumn('category_id', 'bigint', ['unsigned' => true]);
            $table->addIndex(['category_id'], 'category_id');
            $table->addForeignKeyConstraint('category', ['category_id'], ['id'], [], 'category');
        }

        $table->hasIndex('make_model_year') || $table->addUniqueIndex(['make_id', 'model_id', 'year'], 'make_model_year');
        $table->hasColumn('gath_id') || $table->addColumn('gath_id', 'integer', ['notnull' => false]);

        if (!$table->hasColumn('slug')) {
            $table->addColumn('slug', 'string', ['length' => 191]);
            $table->addUniqueIndex(['slug']);
        }

        if (!$table->hasColumn('image_id')) {
            $table->addColumn('image_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('image', ['image_id'], ['id']);
        }

        $table->hasColumn('engine_displacement') || $table->addColumn('engine_displacement', 'decimal', [
            'scale' => 2,
            'notnull' => false,
        ]);

        if (!$table->hasColumn('engine_type_id')) {
            $table->addColumn('engine_type_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('engine_type', ['engine_type_id'], ['id']);
        }

        if (!$table->hasColumn('engine_id')) {
            $table->addColumn('engine_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('engine', ['engine_id'], ['id']);
        }

        $table->hasColumn('power_ps') || $table->addColumn('power_ps', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('power_rpm') || $table->addColumn('power_rpm', 'integer', ['notnull' => false]);
        $table->hasColumn('torque_nm') || $table->addColumn('torque_nm', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('torque_rpm') || $table->addColumn('torque_rpm', 'integer', ['notnull' => false]);
        $table->hasColumn('valves_per_cylinder') || $table->addColumn('valves_per_cylinder', 'integer', ['notnull' => false]);

        if (!$table->hasColumn('fuel_system_id')) {
            $table->addColumn('fuel_system_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('fuel_system', ['fuel_system_id'], ['id']);
        }

        if (!$table->hasColumn('fuel_control_id')) {
            $table->addColumn('fuel_control_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('fuel_control', ['fuel_control_id'], ['id']);
        }

        if (!$table->hasColumn('ignition_id')) {
            $table->addColumn('ignition_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('ignition', ['ignition_id'], ['id']);
        }

        if (!$table->hasColumn('lubrication_system_id')) {
            $table->addColumn('lubrication_system_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('lubrication_system', ['lubrication_system_id'], ['id']);
        }

        if (!$table->hasColumn('cooling_system_id')) {
            $table->addColumn('cooling_system_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('cooling_system', ['cooling_system_id'], ['id']);
        }

        if (!$table->hasColumn('gearbox_id')) {
            $table->addColumn('gearbox_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('gearbox', ['gearbox_id'], ['id']);
        }

        if (!$table->hasColumn('transmission_type_id')) {
            $table->addColumn('transmission_type_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('transmission_type', ['transmission_type_id'], ['id']);
        }

        if (!$table->hasColumn('clutch_id')) {
            $table->addColumn('clutch_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('clutch', ['clutch_id'], ['id']);
        }

        if (!$table->hasColumn('exhaust_system_id')) {
            $table->addColumn('exhaust_system_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('exhaust_system', ['exhaust_system_id'], ['id']);
        }

        if (!$table->hasColumn('front_suspension_id')) {
            $table->addColumn('front_suspension_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('suspension', ['front_suspension_id'], ['id']);
        }

        if (!$table->hasColumn('rear_suspension_id')) {
            $table->addColumn('rear_suspension_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('suspension', ['rear_suspension_id'], ['id']);
        }

        $table->hasColumn('front_tire') || $table->addColumn('front_tire', 'string', ['notnull' => false]);
        $table->hasColumn('rear_tire') || $table->addColumn('rear_tire', 'string', ['notnull' => false]);

        if (!$table->hasColumn('front_brakes_id')) {
            $table->addColumn('front_brakes_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('brake', ['front_brakes_id'], ['id']);
        }

        $table->hasColumn('front_brakes_diameter') || $table->addColumn('front_brakes_diameter', 'integer', ['notnull' => false]);

        if (!$table->hasColumn('rear_brakes_id')) {
            $table->addColumn('rear_brakes_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('brake', ['rear_brakes_id'], ['id']);
        }

        $table->hasColumn('rear_brakes_diameter') || $table->addColumn('rear_brakes_diameter', 'integer', ['notnull' => false]);

        $table->hasColumn('dry_weight') || $table->addColumn('dry_weight', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('full_weight') || $table->addColumn('full_weight', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('seat_height') || $table->addColumn('seat_height', 'integer', ['notnull' => false]);
        $table->hasColumn('front_weight') || $table->addColumn('front_weight', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('rear_weight') || $table->addColumn('rear_weight', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('height') || $table->addColumn('height', 'integer', ['notnull' => false]);
        $table->hasColumn('length') || $table->addColumn('length', 'integer', ['notnull' => false]);
        $table->hasColumn('width') || $table->addColumn('width', 'integer', ['notnull' => false]);
        $table->hasColumn('ground_clearance') || $table->addColumn('ground_clearance', 'integer', ['notnull' => false]);
        $table->hasColumn('wheelbase') || $table->addColumn('wheelbase', 'integer', ['notnull' => false]);
        $table->hasColumn('fuel_capacity') || $table->addColumn('fuel_capacity', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('reserve_fuel_capacity') || $table->addColumn('reserve_fuel_capacity', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('oil_capacity') || $table->addColumn('oil_capacity', 'decimal', ['scale' => 2, 'notnull' => false]);

        if (!$table->hasColumn('starter_id')) {
            $table->addColumn('starter_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('starter', ['starter_id'], ['id']);
        }

        if (!$table->hasColumn('electrical_id')) {
            $table->addColumn('electrical_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('electrical', ['electrical_id'], ['id']);
        }
    }

    /**
     * @param Table $table
     * @throws SchemaException
     */
    private function _name_table(Table $table): void
    {
        $this->_id($table);
        $this->_name($table);
    }

    /**
     * @param Table $table
     * @throws SchemaException
     */
    private function _id(Table $table): void
    {
        if (!$table->hasColumn('id')) {
            $table->addColumn('id', 'bigint', [
                'unsigned' => true,
                'autoincrement' => true,
            ]);

            $table->setPrimaryKey(['id']);
        }
    }

    /**
     * @param Table $table
     * @throws SchemaException
     */
    private function _make_id(Table $table): void
    {
        $table->hasColumn('make_id') || $table->addColumn('make_id', 'bigint', [
            'unsigned' => true,
        ]);
        $table->hasIndex('make_id') || $table->addIndex(['make_id'], 'make_id');
        $table->hasForeignKey('make') || $table->addForeignKeyConstraint('make', ['make_id'], ['id'], []);
    }

    /**
     * @param Table $table
     * @throws SchemaException
     */
    private function _name(Table $table): void
    {
        $table->hasColumn('name') || $table->addColumn('name', 'string', [
            'length' => 191,
            'notnull' => false,
        ]);
        $table->hasIndex('name') || $table->addUniqueIndex(['name'], 'name');
        $table->hasColumn('name_en') || $table->addColumn('name_en', 'string');
    }
}

==> inti-moto-cli-1.1.0-406284.tar: src/Schema/Create.php <==
<?php
declare(strict_types=1);

namespace Inti\Moto\Console\Schema;

use Doctrine\DBAL\Connection;
use Doctrine\DBAL\Schema\SchemaException;
use Doctrine\DBAL\Schema\Table;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Helper\ProgressBar;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Throwable;

use function method_exists;

/**
 * Class CreateSchema
 *
 * @package Inti\Moto\Console\Schema
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-moto-cli
 */
final class Create extends Command
{
    private Connection $conn;

    private array $tables = [
        'make',


        'image',
        'model',
        'category',
        'engine_type',
        'engine',
        'fuel_system',
        'fuel_control',
        'ignition',
        'lubrication_system',
        'cooling_system',
        'gearbox',
        'transmission_type',
        'clutch',
        'exhaust_system',
        'suspension',
        'brake',
        'starter',
        'electrical',
        'bike',
    ];

    public function __construct(Connection $conn)
    {
        parent::__construct('schema:create');
        $this->conn = $conn;
    }

    protected function configure(): void
    {
        $this->setDescription('Stvara potrebne tablice u bazi.');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $output->writeln('<info>Creating tables...</info>');


        try {
            $manager = $this->conn->getSchemaManager();
            $fromSchema = $manager->createSchema();
            $toSchema = clone $fromSchema;

            ProgressBar::setFormatDefinition('tables', ' %current%/%max% %bar% %percent%% -- %message%');
            $progressBar = new ProgressBar($output);
            $progressBar->setFormat('tables');

            foreach ($progressBar->iterate($this->tables) as $tableName) {
                $progressBar->setMessage($tableName);

                $table = $toSchema->hasTable($tableName)
                    ? $toSchema->getTable($tableName)
                    : $toSchema->createTable($tableName);

                if (method_exists($this, $tableName)) {
                    $this->$tableName($table);
                } else {
                    $this->_name_table($table);
                }

                $sql = $fromSchema->getMigrateToSql($toSchema, $this->conn->getDatabasePlatform());

                foreach ($sql as $query) {
                    $this->conn->executeQuery($query);
                }

                $fromSchema = $manager->createSchema();
                $toSchema = clone $fromSchema;
            }

            $output->writeln([
                '',
                '<info>Done!</info>'
            ]);

            return Command::SUCCESS;
        } catch (Throwable $e) {
            $output->writeln([
                'Došlo je do neakve pogreške:',
                isset($query) ? '============================' : '',
                isset($query) ? $query : '',
                '============================',
                $e->getMessage(),
            ]);

            return Command::FAILURE;
        }
    }

    /**
     * @param Table $table
     * @throws SchemaException
     * @noinspection PhpUnusedPrivateMethodInspection
     */
    private function make(Table $table): void
    {
        $this->_id($table);

        $table->addColumn('name', 'string', ['length' => 191]);
        $table->addUniqueIndex(['name'], 'name');

        $table->addColumn('slug', 'string', ['length' => 191]);
        $table->addUniqueIndex(['slug'], 'slug');
    }

    /**
     * @param Table $table
     * @throws SchemaException
     * @noinspection PhpUnusedPrivateMethodInspection
     */
    private function image(Table $table): void
    {
        $this->_id($table);

        if (!$table->hasColumn('url')) {
            $table->addColumn('url', 'string', ['length' => 191]);
            $table->addUniqueIndex(['url'], 'url');
        }
    }

    /**
     * @param Table $table
     * @throws SchemaException
     * @noinspection PhpUnusedPrivateMethodInspection
     */
    private function model(Table $table): void
    {
        $this->_id($table);
        $this->_make_id($table);

        $table->hasColumn('name') || $table->addColumn('name', 'string', [
            'length' => 191,
        ]);
        $table->hasIndex('name') || $table->addIndex(['name'], 'name');
    }

    /**
     * @param Table $table
     * @throws SchemaException
     * @noinspection PhpUnusedPrivateMethodInspection
     */
    private function bike(Table $table): void
    {
        $this->_id($table);

        $this->_make_id($table);

        if (!$table->hasColumn('model_id')) {
            $table->addColumn('model_id', 'bigint', ['unsigned' => true]);
            $table->addIndex(['model_id'], 'model_id');
            $table->addForeignKeyConstraint('model', ['model_id'], ['id'], [], 'model');
        }

        if (!$table->hasColumn('year')) {
            $table->addColumn('year', 'integer');
            $table->addIndex(['year'], 'year');
        }

        if (!$table->hasColumn('category_id')) {
            $table->addColumn('category_id', 'bigint', ['unsigned' => true]);
            $table->addIndex(['category_id'], 'category_id');
            $table->addForeignKeyConstraint('category', ['category_id'], ['id'], [], 'category');
        }

        $table->hasIndex('make_model_year') || $table->addUniqueIndex(['make_id', 'model_id', 'year'], 'make_model_year');
        $table->hasColumn('gath_id') || $table->addColumn('gath_id', 'integer', ['notnull' => false]);

        if (!$table->hasColumn('slug')) {
            $table->addColumn('slug', 'string', ['length' => 191]);
            $table->addUniqueIndex(['slug']);
        }

        if (!$table->hasColumn('image_id')) {
            $table->addColumn('image_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('image', ['image_id'], ['id']);
        }

        $table->hasColumn('engine_displacement') || $table->addColumn('engine_displacement', 'decimal', [
            'scale' => 2,
            'notnull' => false,
        ]);

        if (!$table->hasColumn('engine_type_id')) {
            $table->addColumn('engine_type_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('engine_type', ['engine_type_id'], ['id']);
        }

        if (!$table->hasColumn('engine_id')) {
            $table->addColumn('engine_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('engine', ['engine_id'], ['id']);
        }

        $table->hasColumn('power_ps') || $table->addColumn('power_ps', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('power_rpm') || $table->addColumn('power_rpm', 'integer', ['notnull' => false]);
        $table->hasColumn('torque_nm') || $table->addColumn('torque_nm', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('torque_rpm') || $table->addColumn('torque_rpm', 'integer', ['notnull' => false]);
        $table->hasColumn('valves_per_cylinder') || $table->addColumn('valves_per_cylinder', 'integer', ['notnull' => false]);

        if (!$table->hasColumn('fuel_system_id')) {
            $table->addColumn('fuel_system_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('fuel_system', ['fuel_system_id'], ['id']);
        }

        if (!$table->hasColumn('fuel_control_id')) {
            $table->addColumn('fuel_control_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('fuel_control', ['fuel_control_id'], ['id']);
        }

        if (!$table->hasColumn('ignition_id')) {
            $table->addColumn('ignition_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('ignition', ['ignition_id'], ['id']);
        }

        if (!$table->hasColumn('lubrication_system_id')) {
            $table->addColumn('lubrication_system_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('lubrication_system', ['lubrication_system_id'], ['id']);
        }

        if (!$table->hasColumn('cooling_system_id')) {
            $table->addColumn('cooling_system_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('cooling_system', ['cooling_system_id'], ['id']);
        }

        if (!$table->hasColumn('gearbox_id')) {
            $table->addColumn('gearbox_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('gearbox', ['gearbox_id'], ['id']);
        }

        if (!$table->hasColumn('transmission_type_id')) {
            $table->addColumn('transmission_type_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('transmission_type', ['transmission_type_id'], ['id']);
        }

        if (!$table->hasColumn('clutch_id')) {
            $table->addColumn('clutch_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('clutch', ['clutch_id'], ['id']);
        }

        if (!$table->hasColumn('exhaust_system_id')) {
            $table->addColumn('exhaust_system_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('exhaust_system', ['exhaust_system_id'], ['id']);
        }

        if (!$table->hasColumn('front_suspension_id')) {
            $table->addColumn('front_suspension_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('suspension', ['front_suspension_id'], ['id']);
        }

        if (!$table->hasColumn('rear_suspension_id')) {
            $table->addColumn('rear_suspension_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('suspension', ['rear_suspension_id'], ['id']);
        }

        $table->hasColumn('front_tire') || $table->addColumn('front_tire', 'string', ['notnull' => false]);
        $table->hasColumn('rear_tire') || $table->addColumn('rear_tire', 'string', ['notnull' => false]);

        if (!$table->hasColumn('front_brakes_id')) {
            $table->addColumn('front_brakes_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('brake', ['front_brakes_id'], ['id']);
        }

        $table->hasColumn('front_brakes_diameter') || $table->addColumn('front_brakes_diameter', 'integer', ['notnull' => false]);

        if (!$table->hasColumn('rear_brakes_id')) {
            $table->addColumn('rear_brakes_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('brake', ['rear_brakes_id'], ['id']);
        }

        $table->hasColumn('rear_brakes_diameter') || $table->addColumn('rear_brakes_diameter', 'integer', ['notnull' => false]);

        $table->hasColumn('dry_weight') || $table->addColumn('dry_weight', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('full_weight') || $table->addColumn('full_weight', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('seat_height') || $table->addColumn('seat_height', 'integer', ['notnull' => false]);
        $table->hasColumn('front_weight') || $table->addColumn('front_weight', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('rear_weight') || $table->addColumn('rear_weight', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('height') || $table->addColumn('height', 'integer', ['notnull' => false]);
        $table->hasColumn('length') || $table->addColumn('length', 'integer', ['notnull' => false]);
        $table->hasColumn('width') || $table->addColumn('width', 'integer', ['notnull' => false]);
        $table->hasColumn('ground_clearance') || $table->addColumn('ground_clearance', 'integer', ['notnull' => false]);
        $table->hasColumn('wheelbase') || $table->addColumn('wheelbase', 'integer', ['notnull' => false]);
        $table->hasColumn('fuel_capacity') || $table->addColumn('fuel_capacity', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('reserve_fuel_capacity') || $table->addColumn('reserve_fuel_capacity', 'decimal', ['scale' => 2, 'notnull' => false]);
        $table->hasColumn('oil_capacity') || $table->addColumn('oil_capacity', 'decimal', ['scale' => 2, 'notnull' => false]);

        if (!$table->hasColumn('starter_id')) {
            $table->addColumn('starter_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('starter', ['starter_id'], ['id']);
        }

        if (!$table->hasColumn('electrical_id')) {
            $table->addColumn('electrical_id', 'bigint', [
                'unsigned' => true,
                'notnull' => false,
            ]);
            $table->addForeignKeyConstraint('electrical', ['electrical_id'], ['id']);
        }
    }

    /**
     * @param Table $table
     * @throws SchemaException
     */
    private function _name_table(Table $table): void
    {
        $this->_id($table);
        $this->_name($table);
    }

    /**
     * @param Table $table
     * @throws SchemaException
     */
    private function _id(Table $table): void
    {
        $table->addColumn('id', 'bigint', [
            'unsigned' => true,
            'autoincrement' => true,
        ]);

        $table->setPrimaryKey(['id']);
    }

    /**
     * @param Table $table
     * @throws SchemaException
     */
    private function _make_id(Table $table): void
    {
        $table->hasColumn('make_id') || $table->addColumn('make_id', 'bigint', [
            'unsigned' => true,
        ]);
        $table->hasIndex('make_id') || $table->addIndex(['make_id'], 'make_id');
        $table->hasForeignKey('make') || $table->addForeignKeyConstraint('make', ['make_id'], ['id'], []);
    }

    /**
     * @param Table $table
     * @throws SchemaException
     */
    private function _name(Table $table): void
    {
        $table->hasColumn('name') || $table->addColumn('name', 'string', [
            'length' => 191,
            'notnull' => false,
        ]);
        $table->hasIndex('name') || $table->addUniqueIndex(['name'], 'name');
        $table->hasColumn('name_en') || $table->addColumn('name_en', 'string');
    }
}
